package Sah;

our $VERSION = '0.9.14'; # VERSION

1;
# ABSTRACT: Schema for data structures (specification)

__END__
=pod

=head1 NAME

Sah - Schema for data structures (specification)

=head1 VERSION

version 0.9.14

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

